@@ -1,4 +1,5 @@
-__all__ = ["chef", "rds", "oozie", "oozie_master", "oozie_slave", "default_dj", "log", "scheduler", "web"]
+__all__ = ["chef", "rds", "oozie", "oozie_master", "oozie_slave",
+    "default_dj", "log", "scheduler", "web", "redis-server", "memcache"]
 
 from chef import Chef
 from rds import RDS
@@ -10,4 +11,5 @@ from experimental_dj import ExperimentalDJ
 from log import Log
 from scheduler import Scheduler
 from web import Web
-from redis_server import Redis
\ No newline at end of file
+from redis_server import Redis
+from memcache import Memcache
