@@ -6,9 +6,9 @@ class DefaultDJ(Web):
         tier = "defaultDJ"
         worker = "pju_worker"
         ami = "ami-1327167a"
-        instance_type = "r3.xlarge"
-        run_list = '{"run_list":["recipe[webslave::deploy_dj]"],"qubole_tier":"%s", "worker_name":"%s"}'
-        modules = ["hive_scripts", "hadoop", "hadoop2", "hustler", "hive", "sqoop", "pig", "tapp2", "cloudman"]
+        instance_type = "m1.xlarge"
+        run_list = '{"run_list":["recipe[%swebslave::deploy_dj]"],"qubole_tier":"%s", "worker_name":"%s"}'
+        modules = ["hive_scripts", "hadoop", "hadoop2", "hustler", "hive", "hive13", "hive2", "sqoop", "pig", "tapp2", "cloudman"]
         region = "us-east-1"
         az = "us-east-1b"
         security_groups = ['default']
