@@ -144,7 +144,10 @@ class Oozie(Tier):
         if exit_code == 0:
             logging.info("cluster successfully started. name = %s" % new_cluster_name) 
         else:
-            logging.error("failed to start cluster. exiting")
+            logging.error("failed to start cluster.")
+            # kill the new cluster if it exists
+            kill_cluster_cmd = "%s can_terminate --terminate --termination-after=10 %s" % (self.EASY_HUSTLER_PATH, new_cluster_name) 
+            subprocess.call(kill_cluster_cmd)
             sys.exit(1)
 
     def write_creds_yml(self, env, env_creds, target_path):
