@@ -1,4 +1,5 @@
 import json
+import tempfile
 from subprocess import check_call
 import random
 import socket
@@ -35,6 +36,24 @@ class RDS():
                                action="store_true", help="Use a tunnel through a web node")
         cn_parser.set_defaults(func=self.connect)
 
+        # run query
+        rn_parser = rds_subparser.add_parser("run",
+                                             help="Run the query on the RDS")
+        group = rn_parser.add_mutually_exclusive_group(required=True)
+        group.add_argument("-f", "--file", dest="fname",
+                               help="File from which to run the query")
+        group.add_argument("-e", "--query", dest="query_str",
+                               help="Query string to run")
+        rn_parser.add_argument("-a", "--autocomplete", dest="autocomplete",
+                               action="store_true",
+                               help="enable tab-completion of table and column names (with slower startup)")
+        rn_parser.add_argument("-r", "--replica", dest="replica", default=True,
+                               action="store_true", help="Login into read replica")
+        rn_parser.add_argument("-t", "--tunnel", dest="tunnel",
+                               action="store_true", help="Use a tunnel through a web node")
+        rn_parser.add_argument("-d", "--db", dest="db_name", default="rstore")
+        rn_parser.set_defaults(func=self.run)
+
         #tunnel
         tn_parser = rds_subparser.add_parser("tunnel",
                                              help="Connect to the primary or replica Mysql server through a tunnel on a web node")
@@ -60,7 +79,7 @@ class RDS():
 
         return result != 0
 
-    def connect(self, args):
+    def connect_cmd(self, args):
         knife = Knife()
         creds = knife.get_credentials(args.environment)
         hostname = ""
@@ -85,14 +104,22 @@ class RDS():
             tunnel = SSHTunnel("ec2-user", list[0], hostname, pemfile, 22, 3306, port)
             hostname = "127.0.0.1"
 
+        if args.replica:
+            prompt = args.environment + "-replica"
+        else:
+            prompt = args.environment
         mysql_cmd = ["mysql", "-u", creds["username"],
                      "-p%s" % creds["password"], "-h", hostname, "-P", str(port), "--prompt",
-                     "%s>\_" % args.environment]
+                     "%s>\_" % prompt]
         logging.debug(" ".join(mysql_cmd))
 
         if not args.autocomplete:
             mysql_cmd.append("-A")
 
+        return mysql_cmd
+
+    def connect(self, args):
+        mysql_cmd = self.connect_cmd(args)
         mysql = check_call(mysql_cmd)
 
 
@@ -101,7 +128,7 @@ class RDS():
         self.connect(args)
 
     @staticmethod
-    def run_query(env, tunnel, sql_query):
+    def get_connection(env, tunnel):
         knife = Knife()
         list = knife.search(env, "web")
         creds = knife.get_credentials(env)
@@ -121,13 +148,46 @@ class RDS():
             tunnel = SSHTunnel("ec2-user", list[0], hostname, pemfile, 22, 3306, port)
             hostname = "127.0.0.1"
 
-        #Connect to DB and run query
-        try:
-            con = MySQLdb.connect(hostname, creds["username"], creds["password"], 'rstore', port);
+        #Connect to DB
+        return MySQLdb.connect(hostname, creds["username"], creds["password"], 'rstore', port)
+    
 
+    @staticmethod
+    def run_query(env, tunnel, sql_query):
+        try:
+            con = RDS.get_connection(env, tunnel)
+            con.autocommit(True)
             cur = con.cursor(MySQLdb.cursors.DictCursor)
             cur.execute(sql_query)
             rows = cur.fetchone()
             return rows
         except MySQLdb.Error, e:
             logging.error("Error %d: %s" % (e.args[0], e.args[1]))
+
+    def run(self, args):
+        mysql_cmd = self.connect_cmd(args)
+        mysql_cmd.append(args.db_name)
+        if args.fname is not None:
+            fh = open(args.fname, 'r')
+        else:
+            fd, fname = tempfile.mkstemp()
+            fh = open(fname, 'w')
+            fh.write(args.query_str)
+            fh.close()
+            fh = open(fname, 'r')
+        check_call(mysql_cmd, stdin=fh)
+
+    @staticmethod
+    def get_settings(env, tunnel):
+        try:
+            con = RDS.get_connection(env, tunnel)
+            cur = con.cursor(MySQLdb.cursors.DictCursor)
+            cur.execute("select var, value from settings")
+            rows = cur.fetchall()
+            settings = {}
+            for row in rows:
+                settings[row["var"]] = row["value"]
+            return settings
+        except MySQLdb.Error, e:
+            logging.error("Error %d: %s" % (e.args[0], e.args[1]))
+
