@@ -70,7 +70,7 @@ class Scheduler(Tier):
 
     
     def get_tag(self, args):
-        return "scheduler_%s" % args.environment
+        return "%s-scheduler" % args.environment
 
     def find_scheduler(self, conn, tag):
         reservations = conn.get_all_instances()
