@@ -13,6 +13,7 @@ optparser.parse!
 @@out_path = ARGV[0]
 base_s3_path= ARGV[1]
 tagname= ARGV[2]
+cloud = ARGV[3]
 puts base_s3_path
 puts tagname
 def s3_path_exists?(path)
@@ -32,6 +33,7 @@ def git_tag_exists?(tag, ver)
 end
 
 f = "#{@@out_path}/chef-repo/cookbooks/webslave/attributes/"
+f = "#{@@out_path}/chef-repo/cookbooks/#{cloud}_webslave/attributes" if cloud != "aws"
 
 class TestNode 
   attr_accessor :default  
@@ -51,11 +53,15 @@ exists = true
 unvalidated_packages = []
 ctp.each do |x,y|
   x = x.gsub("_version","")
-  next if x == "chef"
+  next if x == "chef" || x == "hive_0.8" || x == "tapp2"
   puts "checking for #{x}"
   if x == "tapp"
-    exists = git_tag_exists?("#{x}_#{tagname}_#{y}", y)
-  else  
+    if cloud == "aws"
+      exists = git_tag_exists?("#{x}_#{tagname}_#{y}", y)
+    else
+      exists = git_tag_exists?("#{cloud}_#{x}_#{tagname}_#{y}", y) if cloud != "aws"
+    end
+  else
     s3_path = "#{base_s3_path}/#{x}/#{x}-#{y}.tar.gz"
     exists = s3_path_exists?(s3_path)
   end
