@@ -163,7 +163,7 @@ puts nodeinfo.to_json""" % (env, tier)
         print output
         output = Fork.check_output(["knife", "client", "delete", node, "--yes"], stderr=None)
         print output
-        if cw_obj != None:
+        if cw_obj is not None:
             alarms = cw_obj.describe_alarms(alarm_name_prefix=node)
             logging.debug("Alarms for node: " + str(node) + " found = " + str(len(alarms)))
             for a in alarms:
@@ -183,33 +183,31 @@ puts nodeinfo.to_json""" % (env, tier)
                                                        aws_secret_access_key=creds["secret"])
 
         nodes = self.nodes(args.environment)
-        instances = conn.get_only_instances(nodes)
-        # Reap instances of terminated nodes
-        for i in instances:
-            if i.state == "shutting-down" or i.state == "terminated" or i.state == "stopped":
-                self.remove_node(i.id, cw_obj)
+        all_instances = conn.get_only_instances()
+        for n in nodes:
+            n_i = None
+            for i in all_instances:
+                if i.id == n:
+                    n_i = i
+                    break
+            if n_i is None or n_i.state in ["shutting-down", "terminated", "stopped"]:
+                self.remove_node(n, cw_obj)
             else:
-                logging.info("Node: " + str(i.id) + " has state: " + str(i.state))
-            nodes.remove(i.id)
-
-        #Reap unknown instances
-        for node in nodes:
-            self.remove_node(node)
-
-
+                logging.info("Node %s has state = %s" % (n, n_i.state))
+        
     def deploy_lock(self, environment, tunnel, tier, action):
         pemfile = self.get_pemfile(environment)
         creds = self.get_credentials(environment)
         hostname = creds["host"]
         port = 3306
         # Setup a tunnel
-        if tunnel == True:
+        if tunnel:
             list = self.search(environment, "web")
             port = random.randrange(1, 1000) + 33000
             counter = 1
             while not self.checkport(port) and counter < 5:
                 port = random.randrange(1, 1000) + 33000
-                counter = counter + 1
+                counter += 1
 
             if counter > 5:
                 raise RuntimeError("Could not find a free port")
@@ -235,9 +233,9 @@ puts nodeinfo.to_json""" % (env, tier)
                     print "Locked"
                 success = True    
             elif action == "lock":
-                sql_query = "update rstore.deploy_statuses set running = true where running = false"
+                sql_query = "update rstore.deploy_statuses set running = true, updated_at = CURRENT_TIMESTAMP where running = false"
                 if tier != "web":
-                    sql_query = "update rstore.tier_deploy_statuses set running = true where running = false and tier = '%s'" % (tier)
+                    sql_query = "update rstore.tier_deploy_statuses set running = true, updated_at = CURRENT_TIMESTAMP where running = false and tier = '%s'" % (tier)
                 logging.debug(sql_query)
                 cur = con.cursor()
                 cur.execute(sql_query)
@@ -249,9 +247,9 @@ puts nodeinfo.to_json""" % (env, tier)
                     success = False
                 con.commit()
             elif action == "unlock":
-                sql_query = "update rstore.deploy_statuses set running = false where running = true"
+                sql_query = "update rstore.deploy_statuses set running = false, updated_at = CURRENT_TIMESTAMP where running = true"
                 if tier != "web":
-                    sql_query = "update rstore.tier_deploy_statuses set running = false where running = true and tier = '%s'" % (tier)
+                    sql_query = "update rstore.tier_deploy_statuses set running = false, updated_at = CURRENT_TIMESTAMP where running = true and tier = '%s'" % (tier)
                 logging.debug(sql_query)
                 cur = con.cursor()
                 cur.execute(sql_query)
